import * as React from 'react'
import { useDispatch } from 'react-redux'
import authDispatches from './dispatches'

const AuthContext = React.createContext<any>(undefined)

interface IAuthProvider {}
function AuthProvider(props: IAuthProvider) {
    const dispatch = useDispatch()

    const dispatches = authDispatches(dispatch)
    
    return <AuthContext.Provider value={dispatches} {...props} />
}

function useAuthDispatch() {
    const context = React.useContext(AuthContext)
    if (context === undefined) {
        throw new Error('useAuthDispatch must be used within AuthProvider')
    }
    return context
}

export { AuthProvider, useAuthDispatch }