import { Epic, ofType } from 'redux-observable'
import { switchMap } from 'rxjs/operators'
import { Observable } from 'rxjs/Observable'
import 'rxjs/add/observable/from'
import 'rxjs/add/observable/of'
import 'rxjs/add/operator/mergeMap'
import 'rxjs/add/operator/catch'
import { AUTH_ACTIONS } from '../../../actions/types'
import AuthService from '../../../AuthService'

type ResendConfirmationCodeAction = {
    type: string,
    email: string,
}

const resendConfirmationCode: Epic<ResendConfirmationCodeAction, any, any> = (action$, state$) =>
    action$.pipe(
        ofType(AUTH_ACTIONS.RESEND_CONFIRMATION_CODE),
        switchMap(action =>
            AuthService.resendConfirmationCode(
                action.email.split('@')[0],
            ).mergeMap(response => Observable.of(
                { type: AUTH_ACTIONS.CONFIRM_SIGN_UP, response}
            )).catch(error => Observable.of(
                { type: AUTH_ACTIONS.RESEND_CONFIRMATION_CODE_FAILED, error}
            ))
        )
    )

export default resendConfirmationCode