import { ofType, Epic } from 'redux-observable'
import { switchMap } from 'rxjs/operators'
import { Observable } from 'rxjs/Observable'
import 'rxjs/add/observable/from'
import 'rxjs/add/observable/of'
import 'rxjs/add/operator/mergeMap'
import 'rxjs/add/operator/catch'
import { AUTH_ACTIONS } from '../../../actions/types'
import AuthService from '../../../AuthService'

type SignUpAction = {
    type: string,
    email: string,
    password: string,
    firstName: string,
    lastName: string,
}

const signUp: Epic<SignUpAction, any, any> = (action$, state$) =>
    action$.pipe(
        ofType(AUTH_ACTIONS.SIGN_UP),
        switchMap((action) =>
            AuthService.signUp(
                action.email.split('@')[0],
                action.password,
                action.email,
                action.firstName,
                action.lastName,
            ).mergeMap(response => Observable.of(
                { type: AUTH_ACTIONS.CONFIRM_SIGN_UP, response}
            )).catch(error => Observable.of(
                { type: AUTH_ACTIONS.SIGN_UP_FAILED, error },
            ))
        )
    )

export default signUp